#
# spec file for package octave-forge-ltfat
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  ltfat
Name:           octave-forge-%{octpkg}
Version:        2.4.0
Release:        bp154.1.35
Summary:        The Large Time-Frequency Analysis Toolbox for Octave
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io/%{octpkg}/index.html
# Release 2.4.0 currently missing on octave-forge
# Source0:      https://downloads.sourceforge.net/octave/%%{octpkg}-%%{version}.tar.gz
Source0:        https://github.com/ltfat/ltfat/releases/download/2.4.0/ltfat-2.4.0-of.tar.gz
# PATCH-FIX-UPSTREAM ltfat-nsdgt_m-syntax-error.patch gh#ltfat/ltfat#115 badshah400@gmail.com -- Fix syntax error in nsdgt.m to build against octave >= 6; patch taken from upstream git commit
Patch0:         ltfat-nsdgt_m-syntax-error.patch
BuildRequires:  fdupes
BuildRequires:  fftw3-devel
BuildRequires:  fftw3-threads-devel
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  java-devel
BuildRequires:  lapack-devel
BuildRequires:  octave-devel
BuildRequires:  portaudio-devel
Requires:       octave-cli >= 3.8.0

%description
The Large Time/Frequency Analysis Toolbox (LTFAT) is a Matlab/Octave toolbox
for working with time-frequency analysis, wavelets and signal processing.
It is intended both as an educational and a computational tool. The toolbox
provides a large number of linear transforms including Gabor and wavelet
transforms along with routines for constructing windows (filter prototypes)
and routines for manipulating coefficients.
This is part of the Octave-Forge project.

%prep
%autosetup -p1 -c %{name}-%{version}

# REMOVE PREBUILT JAR
find ./ -name "*.jar" -delete -print

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
pushd ./ltfat/inst/blockproc/java/
make %{?_smp_mflags}
popd
%octave_pkg_src

%octave_pkg_build

%install
%octave_pkg_install
%fdupes %{buildroot}%{octpackages_dir}/%{octpkg}-%{version}

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%defattr(-,root,root)
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Sat Jan  9 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add ltfat-nsdgt_m-syntax-error.patch: Fix syntax error in
  nsdgt.m to build against octave >= 6; patch taken from upstream
  git commit and rebased to apply with -p1 (gh#ltfat/ltfat#115).
* Tue Feb 25 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.4.0:
  * Added universal filterbank phase reconstruction function:
    + filterbankconstphase (Thanks to Nicki Holighaus)
  * Added time-frequency jigsaw puzzle tonal-transinet-residual
    separation:
    tfjigsawsep, plottfjigsawsep, demo_tfjigsawsep
    Thanks to Daniel Haider.
  * Added coiflet filters up to K=17.  Thanks to KIMURA Masaru.
  * Added wavelet function generator (supported Cauchy, Morse)
    freqwavelet
  * Function cqtfilters now accepts windows from freqwin.
  * MEX files are now compatible with the new MATLAB 2018a API.
  * Deprecated cqt, icqt, erblett ierblett. Replacements:
    cqt: cqtfilters and filterbank
    icqt: filterbankdual and ifilterbank or ifilterbankiter
    erblett: audfilters with 'erb' and filterbank
    ierblett: filterbankdual and ifilterbank or ifilterbankiter
- Remove explicit blas build dependency, octave pulls in a BLAS
  implementation (blas or openblas, dependent on archictecture)
- Delete the blockproc.jar included in the sources and regenerate
  it by running make before %%octave_pkg_src.
- Add RPM optflags to CFLAGS/CXXFLAGS, otherwise these are not
  taken into account by the Makefiles.
* Wed Jul 18 2018 badshah400@gmail.com
- Update to version 2.3.1:
  * Two additional matching pursuit variants in multidgtrealmp
- Use fdupes to clean up duplicate files.
* Wed Jun  6 2018 badshah400@gmail.com
- Update to version 2.3.0:
  * New function for computing matching pursuit in DGT:
    multidgtrealmp
  * Matching pursuit and orthogonal matching pursuit for general
    frames (for small problems): franamp
  * ltfat_inferno is now the default colormap.
* Sun Jan  1 2017 dmitry_r@opensuse.org
- Update to version 2.2.0
  * New Gabor window generating functions: ptpfun, ptpfundual, pebfun, pebfundual
  * Introduced Mulaclab, a GUI for editing time-frequency representations.
  * Included new colormaps: ltfat_inferno, ltfat_magma, ltfat_plasma,
    ltfat_viridis, ltfat_nicecolormap
* Fri Jun 10 2016 dmitry_r@opensuse.org
- Update to version 2.1.2
  * Improved functions for DGT and DGTREAL phase reconstruction:
    constructphase, constructphasereal
* Tue Oct 27 2015 dmitry_r@opensuse.org
- Update to version 2.1.1
  * New function for computing higher order phase derivatives: gabphasederiv
  * New function doing the adjustable reassignment: gabreassignadjust
  * New function for the Gabor transform phase reconstruction: constructphase, constructphasereal
  * New filterbank-generating function: audfilters
  * New generic quadratic TF distribution function: quadtfdist
  * New functions for reading and writing wav files: wavload, wavsave
* Tue May 12 2015 dmitry_r@opensuse.org
- Update to version 2.1.0
  * New general filterbank generating routine: warpedfilters
  * New filterbank spectrogram reassignment function: filterbankreassign
  * New quadratic time-frequency distributions
  * Better alignment of wavelet filters.
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 2.0.1
